:mod:`kanon.tables.interpolations` --- Interpolations
=====================================================

.. currentmodule:: kanon.tables.interpolations

.. automodapi:: kanon.tables.interpolations
